@@ -29,7 +29,6 @@
 #include <pwd.h>
 
 // Qt
-#include <KDebug>
 #include <QtCore/QDir>
 #include <QtCore/QFileInfo>
 #include <QtCore/QRegExp>
@@ -41,6 +40,7 @@
 #include <KGlobal>
 #include <KSharedConfig>
 #include <KUser>
+#include <KDebug>
 
 #if defined(Q_OS_MAC)
 #include <sys/sysctl.h>
@@ -120,9 +120,10 @@ QString ProcessInfo::format(const QString& input) const
    // search for and replace known marker
    output.replace("%u",userName());
    output.replace("%n",name(&ok));
-   output.replace("%c",formatCommand(name(&ok),arguments(&ok),ShortCommandFormat));
-   output.replace("%C",formatCommand(name(&ok),arguments(&ok),LongCommandFormat));
-   
+   // TODO: un-comment me when ProcessInfo::formatCommand() is implemented.
+   //output.replace("%c",formatCommand(name(&ok),arguments(&ok),ShortCommandFormat));
+   //output.replace("%C",formatCommand(name(&ok),arguments(&ok),LongCommandFormat));
+
    QString dir = validCurrentDir();
    if (output.contains("%D"))
    {
@@ -137,7 +138,7 @@ QString ProcessInfo::format(const QString& input) const
       output.replace("%D", tempDir);
    }
    output.replace("%d",formatShortDir(dir));
-   
+
    // remove any remaining %[LETTER] sequences
    // output.replace(QRegExp("%\\w"), QString());
 
@@ -413,8 +414,8 @@ void UnixProcessInfo::readUserName()
     if (!ok) return;
 
     struct passwd passwdStruct;
-    struct passwd *getpwResult;
-    char *getpwBuffer;
+    struct passwd* getpwResult;
+    char* getpwBuffer;
     long getpwBufferSize;
     int getpwStatus;
 
@@ -583,7 +584,7 @@ private:
 
             QStringList argList = data.split( QChar('\0') );
 
-            foreach ( const QString &entry , argList )
+            foreach ( const QString& entry , argList )
             {
                 if (!entry.isEmpty())
                     addArgument(entry);
@@ -633,7 +634,7 @@ private:
 
             QStringList bindingList = data.split( QChar('\0') );
 
-            foreach( const QString &entry , bindingList )
+            foreach( const QString& entry , bindingList )
             {
                 QString name;
                 QString value;
@@ -996,11 +997,11 @@ SSHProcessInfo::SSHProcessInfo(const ProcessInfo& process)
 
     // SSH options
     // these are taken from the SSH manual ( accessed via 'man ssh' )
-    
+
     // options which take no arguments
-    static const QString noOptionsArguments("1246AaCfgkMNnqsTtVvXxY"); 
+    static const QString noArgumentOptions("1246AaCfgkMNnqsTtVvXxY"); 
     // options which take one argument
-    static const QString singleOptionArguments("bcDeFiLlmOopRSw");
+    static const QString singleArgumentOptions("bcDeFiLlmOopRSw");
 
     if ( ok )
     {
@@ -1018,17 +1019,38 @@ SSHProcessInfo::SSHProcessInfo(const ProcessInfo& process)
          // program name ( expected to be 'ssh' in this case )
          for ( int i = 1 ; i < args.count() ; i++ )
          {
-            // if this argument is an option then skip it, plus any 
-            // following arguments which refer to this option
+            // If this one is an option ...
+            // Most options together with its argument will be skipped.
             if ( args[i].startsWith('-') )
             {
-                QChar argChar = ( args[i].length() > 1 ) ? args[i][1] : '\0';
+                QChar optionChar = ( args[i].length() > 1 ) ? args[i][1] : '\0';
+                // for example: -p2222 or -p 2222 ?
+                bool optionArgumentCombined =  args[i].length() > 2 ;
 
-                if ( noOptionsArguments.contains(argChar) )
-                    continue;
-                else if ( singleOptionArguments.contains(argChar) )
+                if ( noArgumentOptions.contains(optionChar) )
                 {
-                    i++;
+                    continue;
+                }
+                else if ( singleArgumentOptions.contains(optionChar) )
+                {
+                    QString argument ;
+                    if ( optionArgumentCombined )
+                    {
+                        argument = args[i].mid(2);
+                    }
+                    else
+                    {
+                        argument = args[i+1] ;
+                        i++;
+                    }
+
+                    // support using `-l user` to specify username.
+                    if ( optionChar == 'l' )
+                        _user = argument;
+                    // support using `-p port` to specify port.
+                    else if ( optionChar == 'p' )
+                        _port = argument;
+
                     continue;
                 }
             }
@@ -1040,7 +1062,7 @@ SSHProcessInfo::SSHProcessInfo(const ProcessInfo& process)
                 // check to see if only a hostname is specified, or whether
                 // both a username and host are specified ( in which case they
                 // are separated by an '@' character:  username@host )
-            
+
                 int separatorPosition = args[i].indexOf('@');
                 if ( separatorPosition != -1 )
                 {
@@ -1065,7 +1087,7 @@ SSHProcessInfo::SSHProcessInfo(const ProcessInfo& process)
     else
     {
         kWarning() << "Could not read arguments";
-        
+
         return;
     }
 }
@@ -1078,6 +1100,10 @@ QString SSHProcessInfo::host() const
 {
     return _host;
 }
+QString SSHProcessInfo::port() const
+{
+    return _port;
+}
 QString SSHProcessInfo::command() const
 {
     return _command;
@@ -1085,13 +1111,13 @@ QString SSHProcessInfo::command() const
 QString SSHProcessInfo::format(const QString& input) const
 {
     QString output(input);
-   
+
     // test whether host is an ip address
     // in which case 'short host' and 'full host'
     // markers in the input string are replaced with
     // the full address
     bool isIpAddress = false;
-   
+
     struct in_addr address;
     if ( inet_aton(_host.toLocal8Bit().constData(),&address) != 0 )
         isIpAddress = true;
@@ -1105,7 +1131,7 @@ QString SSHProcessInfo::format(const QString& input) const
         output.replace("%h",_host);
     else
         output.replace("%h",_host.left(_host.indexOf('.')));
-    
+
     output.replace("%H",_host);
     output.replace("%c",_command);
 
