@@ -19,7 +19,8 @@
 #ifndef ZMODEM_DIALOG_H
 #define ZMODEM_DIALOG_H
 
-#include <kdialog.h>
+// KDE
+#include <KDialog>
 
 class KTextEdit;
 
@@ -28,25 +29,26 @@ namespace Konsole
 
 class ZModemDialog : public KDialog
 {
-  Q_OBJECT
+Q_OBJECT
+
 public:
-  ZModemDialog(QWidget *parent, bool modal, const QString &caption);
-  
-  /**
-   * Adds a line of text to the progress window
-   */
-  void addProgressText(const QString &);
+    ZModemDialog(QWidget* parent, bool modal, const QString& caption);
 
-  /**
-   * To indicate the process is finished.
-   */
-  void transferDone();
+    /**
+     * Adds a line of text to the progress window
+     */
+    void addProgressText(const QString &);
+
+    /**
+     * To indicate the process is finished.
+     */
+    void transferDone();
+
+private slots:
+    void slotClose();
 
-public Q_SLOTS:
-  void slotClose();
-  
 private:
-  KTextEdit* _textEdit;
+    KTextEdit* _textEdit;
 };
 
 }
